@@ -7,10 +7,13 @@ import sqlparse.keywords
 from typing import Callable
 from sqlglot import exp
 
+from sql_error_categorizer.catalog import ConstraintType, ConstraintColumn, Constraint
+
 from .base import BaseDetector, DetectedError
 from ..query import Query
 from ..sql_errors import SqlErrors
 from ..catalog import Catalog
+from .. import util
 
 
 class ComplicationDetector(BaseDetector):
@@ -66,35 +69,24 @@ class ComplicationDetector(BaseDetector):
 
         return results
 
-    # TODO: refactor
     def com_83_unnecessary_distinct_in_select_clause(self) -> list[DetectedError]:
         '''
-        Flags the unnecessary use of DISTINCT by comparing the proposed query
-        against the correct solution.
+        Flags a SELECT DISTINCT clause that is unnecessary because the selected
+        columns are already unique due to existing constraints.
         '''
-        return []
+        result: list[DetectedError] = []
 
-        results = []
-        if not self.q_ast or not self.s_ast:
-            return results
+        for select in self.query.selects:
+            if not select.distinct:
+                continue
 
-        # Check if the proposed query has a DISTINCT clause.
-        # This can be a boolean `True` or a Dictionary node for `DISTINCT(...)`.
-        q_args = self.q_ast.get('args', {})
-        q_has_distinct = q_args.get('distinct') not in [None, False]
+            # Remove DISTINCT constraint
+            constraints = [c for c in select.output.unique_constraints if c.constraint_type != ConstraintType.DISTINCT]
 
-        # Check if the correct solution has a DISTINCT clause.
-        s_args = self.s_ast.get('args', {})
-        s_has_distinct = s_args.get('distinct') not in [None, False]
+            if len(constraints) > 0:
+                result.append(DetectedError(SqlErrors.COM_83_UNNECESSARY_DISTINCT_IN_SELECT_CLAUSE, (select.sql,)))
 
-        # If the user's query has DISTINCT but the solution doesn't, it's unnecessary.
-        if q_has_distinct and not s_has_distinct:
-            results.append((
-                SqlErrors.COM_83_UNNECESSARY_DISTINCT_IN_SELECT_CLAUSE,
-                "The DISTINCT keyword is used unnecessarily and is not present in the optimal solution."
-            ))
-            
-        return results
+        return result
 
     # TODO: refactor
     def com_84_unnecessary_join(self) -> list[DetectedError]:
@@ -184,11 +176,47 @@ class ComplicationDetector(BaseDetector):
     def com_91_unnecessary_aggregate_function(self) -> list[DetectedError]:
         return []
     
-    # TODO: implement
     def com_92_unnecessary_distinct_in_aggregate_function(self) -> list[DetectedError]:
-        return []
+        '''MIN and MAX never require DISTINCT. For other aggregate functions, DISTINCT is unnecessary if the argument is unique.'''
+
+        results: list[DetectedError] = []
+
+        for select in self.query.selects:
+            select = select.strip_subqueries()
+
+            if not select.ast:
+                continue
+
+            for agg_func in select.ast.find_all(exp.AggFunc):
+                if not isinstance(agg_func.this, exp.Distinct):
+                    continue
+
+                if isinstance(agg_func, (exp.Min, exp.Max)):
+                    results.append(DetectedError(SqlErrors.COM_92_UNNECESSARY_DISTINCT_IN_AGGREGATE_FUNCTION, (str(agg_func),)))
+                    continue
+
+                arg_expr = agg_func.this.expressions   # `.this` is the DISTINCT, `.expressions` are the arguments
+                if not arg_expr:
+                    continue
+
+                for expr in arg_expr:
+                    # Check if the argument is a constant literal
+                    if isinstance(expr, exp.Literal):
+                        results.append(DetectedError(SqlErrors.COM_92_UNNECESSARY_DISTINCT_IN_AGGREGATE_FUNCTION, (str(agg_func),)))
+                        continue
+
+                    # Check if the argument is a column
+                    if isinstance(expr, exp.Column):
+                        column_name = util.ast.column.get_real_name(expr)
+
+                        # Check if the column has a UNIQUE constraint
+                        unique_constraints = [c for c in select.all_constraints if c.constraint_type == ConstraintType.UNIQUE]
+                        for constraint in unique_constraints:
+                            if { ConstraintColumn(column_name, table_idx=select._get_table_idx_for_column(expr)) } == constraint.columns:
+                                results.append(DetectedError(SqlErrors.COM_92_UNNECESSARY_DISTINCT_IN_AGGREGATE_FUNCTION, (str(agg_func),)))
+                                break
+        return results
     
-    # TODO: implement
     def com_93_unnecessary_argument_of_count(self) -> list[DetectedError]:
         return []
     
@@ -196,17 +224,80 @@ class ComplicationDetector(BaseDetector):
     def com_94_unnecessary_group_by_in_exists_subquery(self) -> list[DetectedError]:
         return []
     
-    # TODO: implement
     def com_95_group_by_with_singleton_groups(self) -> list[DetectedError]:
-        return []
+        '''
+        Flags GROUP BY clauses on singleton groups due to the presence
+        of UNIQUE constraints on the grouped columns.
+        '''
+        results: list[DetectedError] = []
+
+        for select in self.query.selects:
+            if not select.group_by:
+                continue
+
+            group_by_constraint = next((c for c in select.all_constraints if c.constraint_type == ConstraintType.GROUP_BY), None)
+            if not group_by_constraint:
+                # No GROUP BY constraint found, meaning GROUP BY clause in invalid. Skip.
+                continue
+
+            constraints = [c for c in select.all_constraints if c.constraint_type == ConstraintType.UNIQUE]
+
+            for constraint in constraints:
+                if constraint.columns.issubset(group_by_constraint.columns):
+                    results.append(DetectedError(SqlErrors.COM_95_GROUP_BY_WITH_SINGLETON_GROUPS, (group_by_constraint, constraint)))
+                    break        
+
+        return results
     
     # TODO: implement
     def com_96_group_by_with_only_a_single_group(self) -> list[DetectedError]:
         return []
     
-    # TODO: implement
     def com_97_group_by_can_be_replaced_by_distinct(self) -> list[DetectedError]:
-        return []
+        '''
+        Flags GROUP BY clauses that can be replaced by SELECT DISTINCT.
+        This occurs when all selected columns are included in the GROUP BY clause
+        and there are no aggregate functions in the SELECT list.
+        '''
+        results: list[DetectedError] = []
+
+        for select in self.query.selects:
+            select = select.strip_subqueries()
+
+            if not select.group_by:
+                continue
+
+            if not select.ast:
+                continue
+
+            has_agg_func = False
+            for expression in select.ast.expressions:
+                if list(expression.find_all(exp.AggFunc)):
+                    has_agg_func = True
+                    break
+
+            if has_agg_func:
+                continue
+
+            select_columns: list[exp.Column] = []
+            for expression in select.ast.expressions:
+                columns = list(expression.find_all(exp.Column))
+                select_columns.extend(columns)
+            
+            group_by_columns: list[exp.Column] = []
+            for expression in select.group_by:
+                columns = list(expression.find_all(exp.Column))
+                group_by_columns.extend(columns)
+
+            select_col_names = {(util.ast.column.get_real_name(col), select._get_table_idx_for_column(col)) for col in select_columns}
+            group_by_col_names = {(util.ast.column.get_real_name(col), select._get_table_idx_for_column(col)) for col in group_by_columns}
+
+            if select_col_names == group_by_col_names:
+                results.append(DetectedError(SqlErrors.COM_97_GROUP_BY_CAN_BE_REPLACED_WITH_DISTINCT, (select_col_names,)))
+
+        return results
+                        
+
     
     # TODO: implement
     def com_98_union_can_be_replaced_by_or(self) -> list[DetectedError]:
@@ -243,7 +334,26 @@ class ComplicationDetector(BaseDetector):
     
     # TODO: implement
     def com_100_order_by_in_subquery(self) -> list[DetectedError]:
-        return []
+        '''
+        Flags when a subquery contains an ORDER BY clause.
+        Subqueries both ORDER BY and LIMIT are considered valid.
+        '''
+
+        results: list[DetectedError] = []
+
+        # nested subqueries are checked multiple times, so track which have been checked
+        checked_subqueries: set[str] = set()
+
+        for select in self.query.selects:
+            for subquery, clause in select.subqueries:
+                if subquery.sql in checked_subqueries:
+                    continue
+
+                checked_subqueries.add(subquery.sql)
+                if subquery.order_by and not subquery.limit:
+                    results.append(DetectedError(SqlErrors.COM_100_ORDER_BY_IN_SUBQUERY, (subquery.sql,)))
+
+        return results
     
     # TODO: implement
     def com_101_inefficient_having(self) -> list[DetectedError]:
