@@ -1,7 +1,8 @@
 from .base import get_type
 from ...catalog import Catalog
 from sqlglot import exp
-from .types import ResultType, AtomicType, DataType
+from .types import ResultType, AtomicType
+from sqlglot.expressions import DataType
 from .util import is_number, error_message
 
 @get_type.register
